searchData={"items":[{"type":"module","title":"Briscola","doc":"Module for the card game Briscola.\nContains modules for cards, decks, players, the game itself,\nas well as a behavior for implementing game strategies.","ref":"Briscola.html"},{"type":"function","title":"Briscola.ranks/0","doc":"Returns a range representing the ranks of the cards.","ref":"Briscola.html#ranks/0"},{"type":"function","title":"Briscola.suits/0","doc":"Returns a list of the valid suits for briscola cards.","ref":"Briscola.html#suits/0"},{"type":"module","title":"Briscola.Card","doc":"Struct for a card in the game of Briscola.\nhttps://en.m.wikipedia.org/wiki/Italian_playing_cards","ref":"Briscola.Card.html"},{"type":"type","title":"Briscola.Card.rank/0","doc":"Possible ranks for a card in a stripped Italian deck.","ref":"Briscola.Card.html#t:rank/0"},{"type":"function","title":"Briscola.Card.score/1","doc":"Returns the point value of a card","ref":"Briscola.Card.html#score/1"},{"type":"function","title":"Briscola.Card.strength/1","doc":"Returns the strength of a card, used to determine a trick winner.","ref":"Briscola.Card.html#strength/1"},{"type":"type","title":"Briscola.Card.suit/0","doc":"The suit of a card.","ref":"Briscola.Card.html#t:suit/0"},{"type":"type","title":"Briscola.Card.t/0","doc":"","ref":"Briscola.Card.html#t:t/0"},{"type":"module","title":"Briscola.Deck","doc":"Struct representing a deck of cards.","ref":"Briscola.Deck.html"},{"type":"function","title":"Briscola.Deck.new/0","doc":"Create a new deck of cards, not shuffled.","ref":"Briscola.Deck.html#new/0"},{"type":"function","title":"Briscola.Deck.shuffle/1","doc":"Shuffle a deck of cards.","ref":"Briscola.Deck.html#shuffle/1"},{"type":"type","title":"Briscola.Deck.t/0","doc":"","ref":"Briscola.Deck.html#t:t/0"},{"type":"function","title":"Briscola.Deck.take/2","doc":"Take a number of cards from the top of the deck.\nThe top of the deck is the beginning of the list of cards.","ref":"Briscola.Deck.html#take/2"},{"type":"module","title":"Briscola.Game","doc":"`Briscola.Game` module implements a struct that represents a game state,\nand functions to manipulate the game state according to the stages of the game.","ref":"Briscola.Game.html"},{"type":"function","title":"Briscola.Game.game_over?/1","doc":"Check if the game is over, i.e. the deck is empty and all players have no cards.","ref":"Briscola.Game.html#game_over?/1"},{"type":"function","title":"Briscola.Game.lead_suit/1","doc":"","ref":"Briscola.Game.html#lead_suit/1"},{"type":"function","title":"Briscola.Game.leaders/1","doc":"Return players in order of highest score to lowest.","ref":"Briscola.Game.html#leaders/1"},{"type":"function","title":"Briscola.Game.new/1","doc":"Create a new game of Briscola.","ref":"Briscola.Game.html#new/1"},{"type":"type","title":"Briscola.Game.new_game_options/0","doc":"Options for creating a new game.\n  Players is the number of players, can be 2 or 4.\n  Goes first is the index of the player who goes first (zero indexed)","ref":"Briscola.Game.html#t:new_game_options/0"},{"type":"function","title":"Briscola.Game.play/2","doc":"","ref":"Briscola.Game.html#play/2"},{"type":"function","title":"Briscola.Game.redeal/1","doc":"Redistribute one card to each player, call this after scoring a trick.\n\nSince the last few turns of the game don't have enough cards to deal to all players,\nit's normal to get back {:error, :not_enough_cards} on the last few turns.","ref":"Briscola.Game.html#redeal/1"},{"type":"function","title":"Briscola.Game.score_trick/1","doc":"Score the current trick, moving the cards to the winning player's pile.\nAlso clears the trick and sets the action to the winning player.","ref":"Briscola.Game.html#score_trick/1"},{"type":"function","title":"Briscola.Game.should_score_trick?/1","doc":"Check if the trick is over, i.e. all players have played a card.","ref":"Briscola.Game.html#should_score_trick?/1"},{"type":"type","title":"Briscola.Game.t/0","doc":"","ref":"Briscola.Game.html#t:t/0"},{"type":"function","title":"Briscola.Game.take_trick/2","doc":"","ref":"Briscola.Game.html#take_trick/2"},{"type":"function","title":"Briscola.Game.trump_suit/1","doc":"","ref":"Briscola.Game.html#trump_suit/1"},{"type":"module","title":"Briscola.Player","doc":"Struct for a player in the game of Briscola.\nPlayers have a hand of playing cards and a pile of won cards.\nThe pile of won cards is used for scoring.","ref":"Briscola.Player.html"},{"type":"function","title":"Briscola.Player.new/0","doc":"Create a new player.","ref":"Briscola.Player.html#new/0"},{"type":"function","title":"Briscola.Player.remove_from_hand/2","doc":"Remove a specific card from a player's hand.","ref":"Briscola.Player.html#remove_from_hand/2"},{"type":"function","title":"Briscola.Player.score/1","doc":"Calculate the score of a player.\nThe score is the sum of the scores of the cards in the player's pile.","ref":"Briscola.Player.html#score/1"},{"type":"type","title":"Briscola.Player.t/0","doc":"","ref":"Briscola.Player.html#t:t/0"},{"type":"behaviour","title":"Briscola.Strategy","doc":"A protocol for defining strategies for playing Briscola.","ref":"Briscola.Strategy.html"},{"type":"callback","title":"Briscola.Strategy.choose_card/2","doc":"Given a game state and a player index, choose a card for that player to play.","ref":"Briscola.Strategy.html#c:choose_card/2"},{"type":"module","title":"Briscola.Strategy.Player","doc":"A briscola strategy implementation that asks a player for a card to play via stdin.","ref":"Briscola.Strategy.Player.html"},{"type":"function","title":"Briscola.Strategy.Player.ask_choice/2","doc":"","ref":"Briscola.Strategy.Player.html#ask_choice/2"},{"type":"module","title":"Briscola.Strategy.Random","doc":"A briscola strategy that chooses a random card from the player's hand.","ref":"Briscola.Strategy.Random.html"},{"type":"module","title":"Briscola.Strategy.Simulator","doc":"A module for simulating games of Briscola using different strategies.","ref":"Briscola.Strategy.Simulator.html"},{"type":"type","title":"Briscola.Strategy.Simulator.log_message/0","doc":"","ref":"Briscola.Strategy.Simulator.html#t:log_message/0"},{"type":"function","title":"Briscola.Strategy.Simulator.new/3","doc":"Create a new simulator with a game and a list of strategies.\nPlayer 0 will use the first strategy, player 1 the second, and so on.","ref":"Briscola.Strategy.Simulator.html#new/3"},{"type":"type","title":"Briscola.Strategy.Simulator.new_options/0","doc":"","ref":"Briscola.Strategy.Simulator.html#t:new_options/0"},{"type":"function","title":"Briscola.Strategy.Simulator.run/1","doc":"Simulate until the game is over.","ref":"Briscola.Strategy.Simulator.html#run/1"},{"type":"function","title":"Briscola.Strategy.Simulator.sim_turn/1","doc":"Simulate a single turn in the game.\nThat may mean playing a card, scoring a trick then redealing, or ending the game.","ref":"Briscola.Strategy.Simulator.html#sim_turn/1"},{"type":"type","title":"Briscola.Strategy.Simulator.t/0","doc":"","ref":"Briscola.Strategy.Simulator.html#t:t/0"},{"type":"module","title":"Briscola.Strategy.Strongest","doc":"A briscola strategy that chooses the strongest card from the player's hand.","ref":"Briscola.Strategy.Strongest.html"},{"type":"task","title":"mix briscola.play","doc":"A mix task to play Briscola.\n\nThis task will start a game of Briscola and allow the player to play against AI.\n\nEnter the number of the card in your hand that you want to play when prompted.\n(1 for the first card, 2 for the second, etc.)\n\nAccepts the following arguments:\n  * `--players` or `-p`: The number of players in the game. Default is 2.\n  * `--strategies` or `-s`: A comma-separated list of AI strategies to use.\n    By default AI will select random cards.\n    The strategy name is the module name, i.e. \"Briscola.Strategy.Random\".","ref":"Mix.Tasks.Briscola.Play.html"},{"type":"function","title":"Mix.Tasks.Briscola.Play.run/1","doc":"","ref":"Mix.Tasks.Briscola.Play.html#run/1"},{"type":"extras","title":"Briscola","doc":"# Briscola\n\nImplementation of the Italian card game [Briscola](https://en.m.wikipedia.org/wiki/Briscola).\n\nComes with a mix task to play on the command line!","ref":"readme.html"},{"type":"extras","title":"Installation - Briscola","doc":"```elixir\ndef deps do\n  [\n    {:briscola, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Play in the command line - Briscola","doc":"```bash\nmix briscola.play\n```","ref":"readme.html#play-in-the-command-line"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}